==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/eo.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Memoro ne validas",
    "Unknown error" : "Nekonata eraro",
    "All files" : "Ĉiuj dosieroj",
    "Saved" : "Konservita",
    "Home" : "Hejmo",
    "Close" : "Fermi",
    "Favorites" : "Favoratoj",
    "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon “{dir}”",
    "Upload cancelled." : "La alŝuto nuliĝis.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne povis alŝutiĝi {filename} ĉar ĝi estas dosierujo aŭ ĝi havas 0 duumokojn",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ne sufiĉas libera spaco: vi alŝutas {size1} sed nur {size2} restas",
    "Uploading..." : "Alŝutante...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosieralŝuto plenumiĝas. Lasi la paĝon nun nuligus la alŝuton.",
    "Actions" : "Agoj",
    "Download" : "Elŝuti",
    "Rename" : "Alinomigi",
    "Delete" : "Forigi",
    "Disconnect storage" : "Malkonekti memoron",
    "Unshare" : "Malkunhavigi",
    "Files" : "Dosieroj",
    "Details" : "Detaloj",
    "Select" : "Elekti",
    "Pending" : "Traktotaj",
    "Unable to determine date" : "Ne eblas determini daton",
    "Invalid path" : "Nevalida vojo",
    "This operation is forbidden" : "Ĉi tiu operacio malpermesatas",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ĉi tiu dosierujo maldisponeblas, bonvolu kontroli la protokolojn aŭ kontakti la administranton",
    "Could not move \"{file}\", target exists" : "Ne eblas movi “{file}”-n, celo jam ekzistas",
    "Could not move \"{file}\"" : "Ne eblas movi “{file}”-n",
    "{newName} already exists" : "{newName} jam ekzistas",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ne ebls alinomigi “{fileName}”, ĝi ne plu ekzistas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "La nomo “{targetName}” jam uzatas en la dosierujo “{dir}”. Bonvolu elekti malsaman nomon.",
    "Could not rename \"{fileName}\"" : "Ne eblas alinomigi “{fileName}”",
    "Could not create file \"{file}\"" : "Ne eblas krei dosieron “{file}”",
    "Could not create file \"{file}\" because it already exists" : "Ne eblas krei dosieron “{file}” ĉar ĝi jam ekzistas",
    "Could not create folder \"{dir}\" because it already exists" : "Ne eblas krei dosierujon “{dir}” ĉar ĝi jam ekzistas",
    "Error deleting file \"{fileName}\"." : "Eraris forigo de dosiero “{fileName}”.",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "_%n folder_::_%n folders_" : ["%n dosierujo","%n dosierujoj"],
    "_%n file_::_%n files_" : ["%n dosiero","%n dosieroj"],
    "{dirs} and {files}" : "{dirs} kaj {files}",
    "You don’t have permission to upload or create files here" : "Vi ne permesatas alŝuti aŭ krei dosierojn ĉi tie",
    "_Uploading %n file_::_Uploading %n files_" : ["Alŝutatas %n dosiero","Alŝutatas %n dosieroj"],
    "New" : "Nova",
    "\"{name}\" is an invalid file name." : "“{name}” estas nevalida dosiernomo.",
    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Memoro de {owner} plenas; dosieroj ne povas alŝutiĝi aŭ sinkroniĝi plu!",
    "Your storage is full, files can not be updated or synced anymore!" : "Via memoro plenas, ne plu eblas ĝisdatigi aŭ sinkronigi dosierojn!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Memoro de {owner} preskaŭ plenas ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Via memoro preskaŭ plenas ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["kongruas kun “{filter}”","kongruas kun “{filter}”"],
    "Path" : "Vojo",
    "_%n byte_::_%n bytes_" : ["%n duumoko","%n duumokoj"],
    "Favorited" : "Pliŝatataj",
    "Favorite" : "Favorato",
    "Folder" : "Dosierujo",
    "New folder" : "Nova dosierujo",
    "{newname} already exists" : "{newname} jam ekzistas",
    "Upload" : "Alŝuti",
    "An error occurred while trying to update the tags" : "Eraris provo ĝisdatigi la etikedojn",
    "A new file or folder has been <strong>created</strong>" : "Nova dosiero aŭ dosierujo <strong>kreiĝis</strong>",
    "A file or folder has been <strong>changed</strong>" : "Dosiero aŭ dosierujo <strong>ŝanĝiĝis</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Dosiero aŭ dosierujo <strong>foriĝis</strong>",
    "A file or folder has been <strong>restored</strong>" : "Dosiero aŭ dosierujo <strong>restaŭriĝis</strong>",
    "You created %1$s" : "Vi kreis %1$s",
    "%2$s created %1$s" : "%2$s kreis %1$s",
    "%1$s was created in a public folder" : "%1$s kreiĝis en publika dosierujo",
    "You changed %1$s" : "Vi ŝanĝis %1$s",
    "%2$s changed %1$s" : "%2$s ŝanĝis %1$s",
    "You deleted %1$s" : "Vi forigis %1$s",
    "%2$s deleted %1$s" : "%2$s forigis %1$s",
    "You restored %1$s" : "Vi restaŭris %1$s",
    "%2$s restored %1$s" : "%2$s restaŭris %1$s",
    "Changed by %2$s" : "Ŝanĝita de %2$s",
    "Deleted by %2$s" : "Forigita de %2$s",
    "Restored by %2$s" : "Restaŭrita de %2$s",
    "Upload (max. %s)" : "Alŝuti (maks. %s)",
    "File handling" : "Dosieradministro",
    "Maximum upload size" : "Maksimuma alŝutogrando",
    "max. possible: " : "maks. ebla: ",
    "Save" : "Konservi",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Per PHP-FPM, ŝanĝoj povas postuli 5 minutojn por aplikiĝi.",
    "Missing permissions to edit from here." : "Mankas permesoj por redakti ekde ĉi tie.",
    "Settings" : "Agordo",
    "WebDAV" : "WebDAV",
    "No files in here" : "Neniu dosiero estas ĉi tie",
    "Upload some content or sync with your devices!" : "Alŝutu iom da enhavo aŭ sinkronigu kun viaj aparatoj!",
    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
    "Select all" : "Elekti ĉion",
    "Upload too large" : "Alŝuto tro larĝa",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "La dosieroj, kiujn vi provas alŝuti, transpasas la maksimuman grandon por dosieralŝutoj en ĉi tiu servilo.",
    "No favorites" : "Neniu pliŝato",
    "Files and folders you mark as favorite will show up here" : "Dosieroj kaj dosierujoj, kiujn vi markas, kiel pliŝatoj, aperos ĉi tie",
    "Text file" : "Tekstodosiero",
    "New text file.txt" : "Nova tekstodosiero.txt",
    "Unknown user" : "Nekonata uzanto"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/eo.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Memoro ne validas",
    "Unknown error" : "Nekonata eraro",
    "All files" : "Ĉiuj dosieroj",
    "Home" : "Hejmo",
    "Close" : "Fermi",
    "Favorites" : "Favoratoj",
    "Could not create folder \"{dir}\"" : "Ne eblas krei dosierujon “{dir}”",
    "Upload cancelled." : "La alŝuto nuliĝis.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Ne povis alŝutiĝi {filename} ĉar ĝi estas dosierujo aŭ ĝi havas 0 duumokojn",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ne sufiĉas libera spaco: vi alŝutas {size1} sed nur {size2} restas",
    "Uploading..." : "Alŝutante...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosieralŝuto plenumiĝas. Lasi la paĝon nun nuligus la alŝuton.",
    "Actions" : "Agoj",
    "Download" : "Elŝuti",
    "Rename" : "Alinomigi",
    "Delete" : "Forigi",
    "Disconnect storage" : "Malkonekti memoron",
    "Unshare" : "Malkunhavigi",
    "Files" : "Dosieroj",
    "Details" : "Detaloj",
    "Select" : "Elekti",
    "Pending" : "Traktotaj",
    "Unable to determine date" : "Ne eblas determini daton",
    "Invalid path" : "Nevalida vojo",
    "This operation is forbidden" : "Ĉi tiu operacio malpermesatas",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ĉi tiu dosierujo maldisponeblas, bonvolu kontroli la protokolojn aŭ kontakti la administranton",
    "group" : "grupo",
    "Remote share" : "Fora kunhavo",
    "Could not move \"{file}\", target exists" : "Ne eblas movi “{file}”-n, celo jam ekzistas",
    "Could not move \"{file}\"" : "Ne eblas movi “{file}”-n",
    "{newName} already exists" : "{newName} jam ekzistas",
    "Could not rename \"{fileName}\", it does not exist any more" : "Ne ebls alinomigi “{fileName}”, ĝi ne plu ekzistas",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "La nomo “{targetName}” jam uzatas en la dosierujo “{dir}”. Bonvolu elekti malsaman nomon.",
    "Could not rename \"{fileName}\"" : "Ne eblas alinomigi “{fileName}”",
    "Could not create file \"{file}\"" : "Ne eblas krei dosieron “{file}”",
    "Could not create file \"{file}\" because it already exists" : "Ne eblas krei dosieron “{file}” ĉar ĝi jam ekzistas",
    "Could not create folder \"{dir}\" because it already exists" : "Ne eblas krei dosierujon “{dir}” ĉar ĝi jam ekzistas",
    "Error deleting file \"{fileName}\"." : "Eraris forigo de dosiero “{fileName}”.",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "_%n folder_::_%n folders_" : ["%n dosierujo","%n dosierujoj"],
    "_%n file_::_%n files_" : ["%n dosiero","%n dosieroj"],
    "{dirs} and {files}" : "{dirs} kaj {files}",
    "You don’t have permission to upload or create files here" : "Vi ne permesatas alŝuti aŭ krei dosierojn ĉi tie",
    "_Uploading %n file_::_Uploading %n files_" : ["Alŝutatas %n dosiero","Alŝutatas %n dosieroj"],
    "New" : "Nova",
    "Unknown user" : "Nekonata uzanto",
    "\"{name}\" is an invalid file name." : "“{name}” estas nevalida dosiernomo.",
    "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Memoro de {owner} plenas; dosieroj ne povas alŝutiĝi aŭ sinkroniĝi plu!",
    "Your storage is full, files can not be updated or synced anymore!" : "Via memoro plenas, ne plu eblas ĝisdatigi aŭ sinkronigi dosierojn!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Memoro de {owner} preskaŭ plenas ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Via memoro preskaŭ plenas ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["kongruas kun “{filter}”","kongruas kun “{filter}”"],
    "Path" : "Vojo",
    "_%n byte_::_%n bytes_" : ["%n duumoko","%n duumokoj"],
    "Favorited" : "Pliŝatataj",
    "Favorite" : "Favorato",
    "Folder" : "Dosierujo",
    "New folder" : "Nova dosierujo",
    "{newname} already exists" : "{newname} jam ekzistas",
    "Upload" : "Alŝuti",
    "An error occurred while trying to update the tags" : "Eraris provo ĝisdatigi la etikedojn",
    "A new file or folder has been <strong>created</strong>" : "Nova dosiero aŭ dosierujo <strong>kreiĝis</strong>",
    "A file or folder has been <strong>changed</strong>" : "Dosiero aŭ dosierujo <strong>ŝanĝiĝis</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Dosiero aŭ dosierujo <strong>foriĝis</strong>",
    "A file or folder has been <strong>restored</strong>" : "Dosiero aŭ dosierujo <strong>restaŭriĝis</strong>",
    "You created %1$s" : "Vi kreis %1$s",
    "%2$s created %1$s" : "%2$s kreis %1$s",
    "%1$s was created in a public folder" : "%1$s kreiĝis en publika dosierujo",
    "You changed %1$s" : "Vi ŝanĝis %1$s",
    "%2$s changed %1$s" : "%2$s ŝanĝis %1$s",
    "You deleted %1$s" : "Vi forigis %1$s",
    "%2$s deleted %1$s" : "%2$s forigis %1$s",
    "You restored %1$s" : "Vi restaŭris %1$s",
    "%2$s restored %1$s" : "%2$s restaŭris %1$s",
    "Changed by %2$s" : "Ŝanĝita de %2$s",
    "Deleted by %2$s" : "Forigita de %2$s",
    "Restored by %2$s" : "Restaŭrita de %2$s",
    "Upload (max. %s)" : "Alŝuti (maks. %s)",
    "Settings" : "Agordo",
    "WebDAV" : "WebDAV",
    "No files in here" : "Neniu dosiero estas ĉi tie",
    "Upload some content or sync with your devices!" : "Alŝutu iom da enhavo aŭ sinkronigu kun viaj aparatoj!",
    "No entries found in this folder" : "Neniu enigo troviĝis en ĉi tiu dosierujo",
    "Select all" : "Elekti ĉion",
    "Upload too large" : "Alŝuto tro larĝa",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "La dosieroj, kiujn vi provas alŝuti, transpasas la maksimuman grandon por dosieralŝutoj en ĉi tiu servilo.",
    "No favorites" : "Neniu pliŝato",
    "Files and folders you mark as favorite will show up here" : "Dosieroj kaj dosierujoj, kiujn vi markas, kiel pliŝatoj, aperos ĉi tie",
    "Text file" : "Tekstodosiero",
    "New text file.txt" : "Nova tekstodosiero.txt"
},
"nplurals=2; plural=(n != 1);");
